from collections import UserDict
from typing import Any


class RequestDict(UserDict):
    """
    Dictionary to be used with the requests' library.
    Does not take None entries, deletes keys that get updated to None and works recursively.

    >>> RequestDict({"a": 2, "b": None, "c": {"d": None}})
    {'a': 2, 'c': {}}
    >>> dict_ = RequestDict({"a": 2})
    >>> dict_["a"] = None
    >>> dict_
    {}
    """
    def __setitem__(self, key: Any, value: Any) -> None:
        """
        Set the value of the dictionary

        :param key: The key to set
        :type key: Any

        :param value: The value to set
        :type value: Any
        """
        if value is not None:
            if isinstance(value, dict):
                value = RequestDict(value)
            return super().__setitem__(key, value)
        if super().__contains__(key):
            return super().__delitem__(key)
        return None



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['plato_helper_py']

package_data = \
{'': ['*'],
 'plato_helper_py': ['.scannerwork/*',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/activerules.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-2.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-3.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/changesets-4.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-1.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-2.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-3.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/component-4.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/context-props.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-2.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-3.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/coverages-4.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-2.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/duplications-3.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-2.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-3.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/measures-4.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/metadata.pb',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-2.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-3.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/source-4.txt',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-2.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-3.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/symbols-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-2.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-3.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb',
                     '.scannerwork/scanner-report/syntax-highlightings-4.pb']}

install_requires = \
['backoff>=2.2,<3.0', 'requests>=2.27,<3.0', 'types-requests>=2.28.11,<3.0.0']

setup_kwargs = {
    'name': 'plato-helper-py',
    'version': '2.1.0',
    'description': 'Helper for the Plato microservice',
    'long_description': None,
    'author': 'Tiago Santos',
    'author_email': 'tiago.santos@vizidox.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)
